unit MainUnit;

interface

uses
	Winapi.Windows, Winapi.Messages, System.SysUtils, System.Variants, System.Classes, Vcl.Graphics,
	Vcl.Controls, Vcl.Forms, Vcl.Dialogs, Vcl.StdCtrls, Vcl.ExtCtrls;

type
	TForm1 = class(TForm)
    ChRadios: TRadioGroup;
		GoButton: TButton;
		AbortButton: TButton;
		ResultScroll: TScrollBox;
		ResultPaint: TPaintBox;
    LogMemo: TMemo;
    Splitter1: TSplitter;
		procedure FormCreate(Sender: TObject);
		procedure GoButtonClick(Sender: TObject);
		procedure AbortButtonClick(Sender: TObject);
    procedure ResultPaintPaint(Sender: TObject);
	protected
		ADData: array of Word;

		procedure ReportErr(CallNom: string; Status: LongWord);
		{ Private declarations }
	public
		{ Public declarations }
	end;

var
	Form1: TForm1;



implementation

{$R *.dfm}

uses
	AIOUSB;

const
	DeviceIndex = 0;
	ChColor: array[$0..$F] of TColor =
	(
		$808080,
		$FF0000,
		$00FF00,
		$FFFF00,
		$0000FF,
		$FF00FF,
		$00FFFF,
		$FFFFFF,
		$808080,
		$FF0000,
		$00FF00,
		$FFFF00,
		$0000FF,
		$FF00FF,
		$00FFFF,
		$FFFFFF
	);

procedure TForm1.AbortButtonClick(Sender: TObject);
begin
	ReportErr('ADC_BulkAbort', ADC_BulkAbort(DeviceIndex));
end;

procedure TForm1.FormCreate(Sender: TObject);
begin
	//`@
end;

procedure TForm1.GoButtonClick(Sender: TObject);
var
	Hz: Double;
	Config: array of Byte;
	iCh: Integer;
	ConfigBufSize, BytesKnown, BytesLeft: LongWord;
	Status: LongWord;

begin
	Hz := 0;
	ReportErr('CTR_StartOutputFreq', CTR_StartOutputFreq(DeviceIndex, 0, @Hz));

	ResultPaint.Width := 1;

	SetLength(Config, 20);
	for iCh := $0 to $F do
		  Config[iCh] := $2
		  ;
	Config[$10] := 0;
	Config[$11] := $05;
	case ChRadios.ItemIndex of
		0: Config[$12] := $00;
		1: Config[$12] := $F0;
	end;
	Config[$13] := 0;
	Config[$14] := $00;
	ConfigBufSize := Length(Config);
	ReportErr('ADC_SetConfig', ADC_SetConfig(DeviceIndex, @Config[0], ConfigBufSize));

	ReportErr('ADC_SetCal', ADC_SetCal(DeviceIndex, ':AUTO:'));

	SetLength(ADData, 16*1024);
	BytesKnown := Length(ADData) * SizeOf(ADData[0]);
	FillChar(ADData[0], BytesKnown, 0);
	ReportErr('ADC_BulkAcquire', ADC_BulkAcquire(DeviceIndex, BytesKnown, @ADData[0]));

	Sleep(1);

	Hz := Length(ADData);
	ReportErr('CTR_StartOutputFreq', CTR_StartOutputFreq(DeviceIndex, 0, @Hz));

	LogMemo.Lines.Add('Acquiring');

	repeat
		Application.ProcessMessages;
		BytesLeft := 0;
		Status := ADC_BulkPoll(DeviceIndex, BytesLeft);
		if Status <> ERROR_SUCCESS then begin
			ReportErr('ADC_BulkPoll', Status);
			ReportErr('ADC_BulkAbort', ADC_BulkAbort(DeviceIndex));
			LogMemo.Lines.Add('Aborted.');
			Exit;
		end;
	until BytesLeft = 0;

	ResultPaint.Width := Length(ADData) + 16;

	Hz := 0;
	ReportErr('CTR_StartOutputFreq', CTR_StartOutputFreq(DeviceIndex, 0, @Hz));

	LogMemo.Lines.Add('Done.');
end;

procedure TForm1.ReportErr(CallNom: string; Status: LongWord);
begin
	if Status = ERROR_SUCCESS then Exit;

	LogMemo.Lines.Add(CallNom + ' Error ' + IntToStr(Status));
end;

procedure TForm1.ResultPaintPaint(Sender: TObject);
var
	iCh, iSamp, dY: Integer;
	YF: Double;

begin
	ResultPaint.Canvas.Brush.Color := $000000;
	ResultPaint.Canvas.FillRect(ResultPaint.ClientRect);
	dY := ResultPaint.Height-8;
	YF := (dY-8) / $FFFF;
	iCh := 0;
	for iSamp := 0 to High(ADData) do begin
		ResultPaint.Canvas.Pixels[8 + iSamp, Round(dY - YF*ADData[iSamp])] := ChColor[iCh];
		iCh := (iCh + 1) mod 16;
	end;

end;

end.
